@@ -64,27 +64,28 @@ class _NoValue:
     pass
 
 
-def build_simple(fs: List[SimpleFilter], combiner) -> str:
+def build_simple(fs: List[SimpleFilter], combiner, exempt) -> str:
     cs = []
     for f in fs:
         if isinstance(f, AND):
-            c = build_simple(f.conditions, 'AND')
+            c = build_simple(f.conditions, 'AND', exempt)
             if c:
                 cs.append(f'({c})')
         elif isinstance(f, OR):
-            c = build_simple(f.conditions, 'OR')
+            c = build_simple(f.conditions, 'OR', exempt)
             if c:
                 cs.append(f'({c})')
         else:
             r, o, v = f
-            if o in ('=', '=='):
-                o = '='
-            if o in ('!=', '<>', '/='):
-                o = '!='
-            if isinstance(v, str):
-                v.replace("'", "''")
-                v = f"'{v}'"
-            cs.append(f'("{r}" {o} {v})')
+            if r not in exempt:
+                if o in ('=', '=='):
+                    o = '='
+                if o in ('!=', '<>', '/='):
+                    o = '!='
+                if isinstance(v, str):
+                    v.replace("'", "''")
+                    v = f"'{v}'"
+                cs.append(f'(s.{r} {o} {v})')
     return f" {combiner} ".join(cs)
 
 
@@ -98,9 +99,10 @@ def build_expression(s3path: S3Path, columns: Dict[str, Type], filters: FilterRe
             query += ' WHERE '
             query += ' AND '.join(c.get_sql_fragment(f"s.{k}") for k, c in object_filters.items())
     else:
-        fs = build_simple(filters, 'AND')
+        fs = build_simple(filters, 'AND', s3path.params.keys())
         if fs:
             query += f" WHERE {fs}"
+    print(query)
     return query
 
 
@@ -234,9 +236,11 @@ class S3Access:
         else:
             def chk(sf: SimpleFilter) -> bool:
                 if isinstance(sf, AND):
-                    return all(chk(cn) for cn in sf.conditions)
+                    checks = [chk(cn) for cn in sf.conditions]
+                    return all(checks)
                 elif isinstance(sf, OR):
-                    return any(chk(cn) for cn in sf.conditions)
+                    checks = [chk(cn) for cn in sf.conditions]
+                    return any(checks)
                 else:
                     r, o, v = sf
                     if r not in path.params:
